#!/bin/sh
### BEGIN INIT INFO
# Provides:          anope
# Required-Start:    $local_fs $network $remote_fs $syslog
# Required-Stop:     $local_fs $network $remote_fs $syslog
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Short-Description: A set of IRC Services
# Description:       Anope offers various services to maintain your IRC network.
#                    The following main services are included: NickServ,
#                    OperServ, BotServ, and HostServ.
### END INIT INFO

# Author: Dominic Hargreaves <dom@earth.li>

# Do NOT "set -e"

# PATH should only include /usr/* if it runs after the mountnfs.sh script
PATH=/sbin:/usr/sbin:/bin:/usr/bin
DESC="IRC services"
NAME=anope
DAEMON=/usr/sbin/anope
DAEMON_ARGS="--confdir=/etc/$NAME --dbdir=/var/lib/$NAME/db --logdir=/var/log/$NAME --modulesdir=/usr/lib/$NAME --localedir=/usr/share/$NAME/locale"
PIDDIR=/var/run/$NAME
PIDFILE=$PIDDIR/$NAME.pid
SCRIPTNAME=/etc/init.d/$NAME

# Exit if the package is not installed
[ -x "$DAEMON" ] || exit 0

# Read configuration variable file if it is present
[ -r /etc/default/$NAME ] && . /etc/default/$NAME

# Load the VERBOSE setting and other rcS variables
. /lib/init/vars.sh

# Define LSB log_* functions.
# Depend on lsb-base (>= 3.2-14) to ensure that this file is present
# and status_of_proc is working.
. /lib/lsb/init-functions

#
# Function that starts the daemon/service
#
do_start()
{
	# Return
	#   0 if daemon has been started
	#   1 if daemon was already running
	#   2 if daemon could not be started
    mkdir -p $PIDDIR
    chown irc $PIDDIR
	start-stop-daemon --start --chuid irc --quiet --pidfile $PIDFILE --exec $DAEMON --test > /dev/null \
		|| return 1
	start-stop-daemon --start --chuid irc --quiet --pidfile $PIDFILE --exec $DAEMON -- \
		$DAEMON_ARGS \
		|| return 2
}

#
# Function that stops the daemon/service
#
do_stop()
{
	# Return
	#   0 if daemon has been stopped
	#   1 if daemon was already stopped
	#   2 if daemon could not be stopped
	#   other if a failure occurred
	start-stop-daemon --stop --quiet --retry=TERM/30/KILL/5 --pidfile $PIDFILE --name $NAME
	RETVAL="$?"
	[ "$RETVAL" = 2 ] && return 2
	# Wait for children to finish too if this is a daemon that forks
	# and if the daemon is only ever run from this initscript.
	# If the above conditions are not satisfied then add some other code
	# that waits for the process to drop all resources that could be
	# needed by services started subsequently.  A last resort is to
	# sleep for some time.
	start-stop-daemon --stop --quiet --oknodo --retry=0/30/KILL/5 --exec $DAEMON
	[ "$?" = 2 ] && return 2
	# Many daemons don't delete their pidfiles when they exit.
	rm -f $PIDFILE
	return "$RETVAL"
}

#
# Function that sends a SIGHUP to the daemon/service
#
do_reload() {
	#
	# If the daemon can reload its configuration without
	# restarting (for example, when it is sent a SIGHUP),
	# then implement that here.
	#
	start-stop-daemon --stop --signal 1 --quiet --pidfile $PIDFILE --name $NAME
	return 0
}

case "$1" in
  start)
    if [ "$START" = "yes" ]; then
	  [ "$VERBOSE" != no ] && log_daemon_msg "Starting $DESC" "$NAME"
	  do_start
	  case "$?" in
		  0|1) [ "$VERBOSE" != no ] && log_end_msg 0 ;;
		  2) [ "$VERBOSE" != no ] && log_end_msg 1 ;;
	  esac
    fi
	;;
  stop)
	[ "$VERBOSE" != no ] && log_daemon_msg "Stopping $DESC" "$NAME"
	do_stop
	case "$?" in
		0|1) [ "$VERBOSE" != no ] && log_end_msg 0 ;;
		2) [ "$VERBOSE" != no ] && log_end_msg 1 ;;
	esac
	;;
  status)
	status_of_proc "$DAEMON" "$NAME" && exit 0 || exit $?
	;;
  reload|force-reload)
    if [ "$START" = "yes" ]; then
	  log_daemon_msg "Reloading $DESC" "$NAME"
	  do_reload
	  log_end_msg $?
    else
      log_warning_msg "$DESC not running so not reloading"
      exit 7
    fi
	;;
  restart)
    if [ "$START" = "yes" ]; then
	  log_daemon_msg "Restarting $DESC" "$NAME"
	  do_stop
	  case "$?" in
	    0|1)
		  do_start
		  case "$?" in
			  0) log_end_msg 0 ;;
			  1) log_end_msg 1 ;; # Old process is still running
			  *) log_end_msg 1 ;; # Failed to start
		  esac
		  ;;
	    *)
		  # Failed to stop
		  log_end_msg 1
		  ;;
	  esac
    fi
	;;
  *)
	#echo "Usage: $SCRIPTNAME {start|stop|restart|reload|force-reload}" >&2
	echo "Usage: $SCRIPTNAME {start|stop|status|restart|force-reload}" >&2
	exit 3
	;;
esac

:
